@@ -54,6 +54,9 @@ debug = 0
 # Variables - Change version
 arch_type = ''
 pre_value = ''
+version_file1 = ''
+version_file2 = ''
+nocommit = 0
 # Variables - Change version
 
 # Variables - Sync repository
@@ -91,6 +94,7 @@ def main(argv):
     global encoded_string 
     global url
     global debug
+    global nocommit
     # Variables - Deploy AWX
     
     # Variables - Nexus
@@ -112,11 +116,14 @@ def main(argv):
     global arch_type
     global change_type
     global pre_value
+    global version_file1
+    global version_file2
     # Variables - Change version
     
     global branch
     global commit_message
     
+    
     # Variables - generate file
     global filename_gen
     
@@ -140,7 +147,7 @@ def main(argv):
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
                                                 "file=", "awxhost=","--host=",
                                                 "format=",
-                                                "type=", "archtype=", "prevalue=",
+                                                "type=", "archtype=", "prevalue=","file2=","nocommit",
                                                 "message=", "branch=",
                                                 "projectkey=", "projectname=",
                                                 "debug",
@@ -198,17 +205,19 @@ def main(argv):
                 print("Or")
                 print("python -m artify --command deltav --type <version_change> --archtype <architecture_type>")
                 print("Mandatory argument(s): ")
-                print("-t, --type          Type of version change: major, minor, patch")
-                print("e.g --type major    1.0.0.0 => 2.0.0.0")
-                print("e.g --type minor    1.0.0.0 => 1.1.0.0")
-                print("e.g --type patch    1.0.0.0 => 1.0.1.0")
+                print("-t, --type          Type of version change: major, minor, patch, auto")
+                print("e.g --type major    1.0.0-alpha => 2.0.0-alpha")
+                print("e.g --type minor    1.0.0       => 1.1.0")
+                print("e.g --type patch    1.0.0-beta => 1.0.1-beta")
                 print("e.g --type build    1.0.0.0 => 1.0.0.1   Experimental")
-                
+                print("e.g --type auto     1.0.0 => 1.0.0-build.1") 
                 print("e.g --archtype npm, gradle, maven, flutter, dotnet, netcore")
                 print("\nOptional arguments: ")
                 print("-b, --branch        Branch to commit code changes. Default: develop")
                 print("--preValue          Prerelease version value e.g SNAPHOT, RELEASE, BUILD, beta, alpa")
-               
+                print("--nocommit     Does not create feature branch with version change")
+                print("-f, --file     File name that you want to update version number. It should be relative to artify execution directory ")
+                print("--file2        An additional file that you want to update version number. It should be relative to artify execution")
                 return sys.exit(0)
             elif arg == 'create':
                 print('')
@@ -248,6 +257,8 @@ def main(argv):
                 return sys.exit(0)
         elif opt == "--debug":
             debug = 1
+        elif opt == "--nocommit":
+            nocommit = 1
         elif opt in ("-c", "--command"):
             action = arg
             if action == '':
@@ -259,6 +270,11 @@ def main(argv):
         elif opt == "--proxysec":
             proxies['https'] = arg    
             
+        elif opt == '--file2':
+            if action == 'deltav':
+                version_file2 = arg 
+            else:
+                print("Invalid command specified: param: --file2")   
         ## Deploy-artifact-awx-host params START
         elif opt in ("-f", "--file", "--format"):
             if action == 'nexus':
@@ -283,6 +299,8 @@ def main(argv):
                 if archive_format == '':
                     print('Please specify archive format e.g zip, tar, gztar, bztar, xztar')
                     return sys.exit(2)
+            elif action == 'deltav':
+                version_file1 = arg
             else:
                 print("Invalid command specified: param: -f")
                      
