@@ -32,8 +32,13 @@ def setup_variables():
         else:
             if 'master' == __main__.branch_name or __main__.branch_name.startswith('release'):
                 __main__.repository_name = 'egov-releases'
+            elif 'staging' == __main__.branch_name:
+                 __main__.repository_name = 'egov-staging'
+            elif 'hotfix-deploy' in __main__.branch_name:
+                 __main__.repository_name = 'egov-snapshots' 
             else:
                 __main__.repository_name = 'egov-snapshots'
+            print("INFO: Nexus repository used: ", __main__.repository_name)
                 
     if __main__.nexus_format == 'raw' and __main__.directory == '':
         print("RAW nexus repository format requires a directory")
@@ -129,7 +134,7 @@ def upload_nexus_maven():
     
     if ver:
         if __main__.debug == 1:
-            print("Version number found: ", ver.group(1))
+            print("Version number found: ", ver.group(0))
     else:
         print("No version number found in file name specified")
         return __main__.sys.exit(1)
@@ -152,7 +157,13 @@ def upload_nexus_maven():
         extension = file_extension[1:]
         versionnumber = ver.group(0)
         # actual_artifact_name = '-'.join(artname_lst[:-1])
-        
+    
+    if __main__.debug == 1:
+        print("Group ID: ", __main__.group_id)
+        print("Artifact ID: ", actual_artifact_name)
+        print("Version number: ", versionnumber)
+        print("Extension: ", extension)
+    
     files = {
         'maven2.groupId': (None, __main__.group_id),
         'maven2.artifactId': (None, actual_artifact_name),
@@ -163,6 +174,8 @@ def upload_nexus_maven():
     }
 
     response = __main__.requests.post(url=__main__.repository_full_url, params=params, files=files, auth=__main__.auth, proxies=__main__.proxies, verify=False)
+    if __main__.debug == 1:
+        print("Detailed response: ", response.content)
     if response.status_code == 204:
         print("Nexus Upload successful")
         return __main__.sys.exit(0)
@@ -172,4 +185,5 @@ def upload_nexus_maven():
     else:
         print("Nexus Upload failed")
         print("Status code: ", response.status_code)
+     
         return __main__.sys.exit(1)
