@@ -35,6 +35,9 @@ def commit_push_changes(message):
             __main__.arch_type = 'flutter'
             filepath = __main__.os.path.join(path,'pubspec.yaml')
             version = change_version.get_version(filepath)
+            
+        if __main__.debug == 1:
+            print("DEBUG: Project type found: ", __main__.arch_type)
 
         # To-do Extract version number for .NET type project
 
